@@ -41,7 +41,16 @@ class Hash(proto.Message):
     """
 
     class HashType(proto.Enum):
-        r"""The algorithm used to compute the hash."""
+        r"""The algorithm used to compute the hash.
+
+        Values:
+            HASH_TYPE_UNSPECIFIED (0):
+                Unspecified.
+            SHA256 (1):
+                SHA256 hash.
+            MD5 (2):
+                MD5 hash.
+        """
         HASH_TYPE_UNSPECIFIED = 0
         SHA256 = 1
         MD5 = 2
