@@ -50,7 +50,16 @@ class YumArtifact(proto.Message):
     """
 
     class PackageType(proto.Enum):
-        r"""Package type is either binary or source."""
+        r"""Package type is either binary or source.
+
+        Values:
+            PACKAGE_TYPE_UNSPECIFIED (0):
+                Package type is not specified.
+            BINARY (1):
+                Binary package (.rpm).
+            SOURCE (2):
+                Source package (.srpm).
+        """
         PACKAGE_TYPE_UNSPECIFIED = 0
         BINARY = 1
         SOURCE = 2
